@@ -16,7 +16,6 @@
 #include "link-includes.h"
 
 /* Invariant: Leaf if child==NULL */
-typedef struct CNode_s CNode;
 struct CNode_s {
   char  * label;
   CNode * child;
@@ -24,7 +23,4 @@ struct CNode_s {
   int   start, end;
 };
 
-CNode * linkage_constituent_tree(Linkage linkage);
-void    linkage_free_constituent_tree(CNode * n);
-
 #endif
