@@ -15,6 +15,7 @@
 
 void safe_strcpy(char *u, char * v, int usize);
 void safe_strcat(char *u, char *v, int usize);
+char *safe_strdup(char *u);
 void xfree(void *, int);
 void exfree(void *, int);
 void free_disjuncts(Disjunct *);
@@ -47,6 +48,8 @@ Exp *       copy_Exp(Exp *);
 
 Connector * init_connector(Connector *c);
 
+void init_x_table(Sentence sent);
+
 /* utility routines moved from parse.c */
 int sentence_contains(Sentence sent, char * s);
 void set_is_conjunction(Sentence sent);
